PQueue

Struct PQueue 

pub struct PQueue<T, W>
where T: Eq + Hash, W: FloatCore,
{ /* private fields */ }
Max priority queue that can properly handle floats.

Implementations

Source

impl<T, W> PQueue<T, W>
where T: Eq + Hash, W: FloatCore,

pub fn new() -> Self

Make a new queue.

pub fn with_capacity(capacity: usize) -> Self

Make a queue with pre-allocated size.

pub fn from_iterator<I>(iter: I) -> Self
where I: Iterator<Item = (T, W)>,

Make a queue from an iterator.

pub fn push(&mut self, item: T, weight: W) -> Option<OrderedFloat<W>>

Insert the item, weight pair into the queue. If an element equal to item is already in the queue, its priority is updated and the old priority is returned in Some; otherwise, item is inserted with priority and None is returned.

pub fn pop(&mut self) -> Option<(T, W)>

Removes the item with the greatest priority from the priority queue and returns the pair item, weight, or None if the queue is empty.

pub fn remove(&mut self, item: T) -> Option<(T, W)>

Remove an arbitrary element from the priority queue. Returns the item, weight couple or None if the item is not found in the queue. The operation is performed in O(log(N)) time (worst case).

pub fn is_empty(&self) -> bool

True if the queue has no elements.

pub fn len(&self) -> usize

Current number of elements in the queue.

pub fn iter(&self) -> impl Iterator<Item = (T, W)> + '_
where T: Clone,

Iterator over the elements in the queue.