pub struct PQueue<T, W>{ /* private fields */ }Expand description
Max priority queue that can properly handle floats.
Implementations
Sourceimpl<T, W> PQueue<T, W>
impl<T, W> PQueue<T, W>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Make a queue with pre-allocated size.
Sourcepub fn from_iterator<I>(iter: I) -> Self
pub fn from_iterator<I>(iter: I) -> Self
Make a queue from an iterator.
Sourcepub fn push(&mut self, item: T, weight: W) -> Option<OrderedFloat<W>>
pub fn push(&mut self, item: T, weight: W) -> Option<OrderedFloat<W>>
Insert the item, weight pair into the queue.
If an element equal to item is already in the queue, its priority is updated and the old
priority is returned in Some; otherwise, item is inserted with priority and None is returned.
Sourcepub fn pop(&mut self) -> Option<(T, W)>
pub fn pop(&mut self) -> Option<(T, W)>
Removes the item with the greatest priority from the priority queue and returns the pair
item, weight, or None if the queue is empty.