pub fn incremental_refinement_with_context<R: RedgeContainers, S, L, P>(
context: &mut RemeshingContext<S, R>,
parameters: RemeshingParametersWithoutCollapse<S>,
adaptive_target_length: L,
_reproject: P,
) -> usizeExpand description
Strictly increase the number of vertices in a mesh via subdivision. Note that it is possible that if this method returns 0, that calling the method again will produce more edges due to equalization and relaxation. Currently, reprojection doesn’t do anything.
Returns the number of added elements (could be less than parameters.target_additional_vertices).