pub struct RemeshingContext<S: RealField + FloatCore, R: RedgeContainers> {
pub queue: PQueue<EdgeId, S>,
pub mesh: Redge<R>,
pub modified_vertices: Vec<VertId>,
pub modified_faces: Vec<FaceId>,
}Expand description
Input argument for remeshing.
Fields
queue: PQueue<EdgeId, S>Priority queue.
mesh: Redge<R>Mesh that will be remeshed.
modified_vertices: Vec<VertId>Vertices that have been modified since the last call to remeshing.
modified_faces: Vec<FaceId>Faces that have been modified since the last call to remeshing.
Implementations
Sourceimpl<S, R> RemeshingContext<S, R>
impl<S, R> RemeshingContext<S, R>